# Basic example

This example demonstrates the basic functionality of the Panel of Agents.
In this example, we have a simple panel of agents that have a specific focus.
None of the agents have additional capabilities they can use to help with their focus.

## Setup
